@@ -1,13 +1,13 @@
 #object = list(observations = observations, params,predictionLocations = predictionLocations)
 
-estimateParameters.rtop = function(object,...) {
-  if (!inherits(object$params,"rtopParams")) object$params = getRtopParams(object$params, 
+estimateParameters.rtop = function(object, params = list(), ...) {
+  if (!inherits(object$params,"rtopParams")) object$params = getRtopParams(object$params, newPar = params, 
       formulaString = object$formulaString, observations = object$observations)
   rtopFitVariogram(object, ...)
 }
 
-spatialPredict.rtop = function(object, ...) {
-  if (!inherits(object$params,"rtopParams")) object$params = getRtopParams(object$params, 
+spatialPredict.rtop = function(object, params = list(), ...) {
+  if (!inherits(object$params,"rtopParams")) object$params = getRtopParams(object$params, newPar = params,
       formulaString = object$formulaString, observations = object$observations)
   rtopKrige(object, ...)
 }
@@ -22,7 +22,7 @@ methodParameters.rtop = function(object, ...) {
   mpar = paste("c(",mpar,")")
   methodParameters = paste(mp,"vmodel$params = ",mpar,"\n")
   object$methodParameters = paste(methodParameters,"object$variogramModel = vmodel")  
-  object = NextMethod(object)
+ # object = NextMethod(object)
   object
 #  eval(parse(text = mp))
 }
\ No newline at end of file
